#
# Copyright (C) 2008 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_QTOPIA) += qtopia

#
# Paths and names
#
QTOPIA_VERSION		:= 4.3.3
QTOPIA			:= qtopia-core-opensource-src-$(QTOPIA_VERSION)
QTOPIA_SUFFIX		:= tar.gz
QTOPIA_URL		:= ftp://ftp.trolltech.com/qt/source/$(QTOPIA).$(QTOPIA_SUFFIX)
QTOPIA_SOURCE		:= $(SRCDIR)/$(QTOPIA).$(QTOPIA_SUFFIX)
QTOPIA_DIR		:= $(BUILDDIR)/$(QTOPIA)


# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

qtopia_get: $(STATEDIR)/qtopia.get

$(STATEDIR)/qtopia.get: $(qtopia_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(QTOPIA_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, QTOPIA)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

qtopia_extract: $(STATEDIR)/qtopia.extract

$(STATEDIR)/qtopia.extract: $(qtopia_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(QTOPIA_DIR))
	@$(call extract, QTOPIA)
	@$(call patchin, QTOPIA)
	@for file in $(QTOPIA_DIR)/mkspecs/qws/linux-ptx-g++/*.in; do \
		sed -e "s,@COMPILER_PREFIX@,$(COMPILER_PREFIX),g" $$file > $${file%%.in}; \
	done
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

qtopia_prepare: $(STATEDIR)/qtopia.prepare

# don't use CROSS_ENV. Qt uses mkspecs for instead.
QTOPIA_ENV	:= $(CROSS_ENV_PKG_CONFIG)
QTOPIA_PATH	:= PATH=$(CROSS_PATH)
QTOPIA_MAKEVARS	:= INSTALL_ROOT=$(SYSROOT)

#
# autoconf
#
# add "-L$(QTOPIA_DIR)/lib" first to make sure builddir is searched before sysroot
# this way we avoid patching $(sysroot)/usr/lib/*.prl (these contain "-L/usr/lib")
QTOPIA_AUTOCONF := \
	-release \
	-fast \
	-no-largefile \
	-no-exceptions \
	-no-accessibility \
	-no-sql-ibase \
	-no-sql-mysql \
	-no-sql-odbc \
	-no-sql-psql \
	-no-sql-sqlite \
	-no-sql-sqlite2 \
	-no-qt3support \
	-no-mmx \
	-no-3dnow \
	-no-sse \
	-no-sse2 \
	-no-openssl \
	-no-optimized-qmake \
	-no-nis \
	-no-cups \
	-no-iconv \
	-pch \
	-embedded $(call remove_quotes,$(PTXCONF_ARCH)) \
	-qt-gfx-linuxfb \
	-qt-kbd-tty \
	-qt-mouse-pc \
	-no-glib \
	-qt-decoration-styled \
	-depths 8,16 \
	-prefix /usr \
	-no-armfpa \
	-I$(SYSROOT)/include \
	-I$(SYSROOT)/usr/include \
	-L$(QTOPIA_DIR)/lib \
	-L$(SYSROOT)/lib \
	-L$(SYSROOT)/usr/lib \
	-xplatform qws/linux-ptx-g++ \
	-make libs \
	-make tools \
	-make demos \
	-verbose

# maybe later:
#
# -iwmmxt

ifdef PTXCONF_QTOPIA_EXAMPLES
QTOPIA_AUTOCONF += -make examples
else
QTOPIA_AUTOCONF += -nomake examples
endif

# PNG support
ifdef PTXCONF_QTOPIA_PNG_NONE
QTOPIA_AUTOCONF += -no-libpng
endif
ifdef PTXCONF_QTOPIA_PNG_INTERNAL
QTOPIA_AUTOCONF += -qt-libpng
endif
ifdef PTXCONF_QTOPIA_PNG_SYSTEM
QTOPIA_AUTOCONF += -system-libpng
endif

# MNG support
ifdef PTXCONF_QTOPIA_MNG_NONE
QTOPIA_AUTOCONF += -no-libmng
endif
ifdef PTXCONF_QTOPIA_MNG_INTERNAL
QTOPIA_AUTOCONF += -qt-libmng
endif
ifdef PTXCONF_QTOPIA_MNG_SYSTEM
QTOPIA_AUTOCONF += -system-libmng
endif

# TIFF support
ifdef PTXCONF_QTOPIA_TIFF_NONE
QTOPIA_AUTOCONF += -no-libtiff
endif
ifdef PTXCONF_QTOPIA_TIFF_INTERNAL
QTOPIA_AUTOCONF += -qt-libtiff
endif
ifdef PTXCONF_QTOPIA_TIFF_SYSTEM
QTOPIA_AUTOCONF += -system-libtiff
endif

# GIF support
ifdef PTXCONF_QTOPIA_GIF_NONE
QTOPIA_AUTOCONF += -no-gif
endif
ifdef PTXCONF_QTOPIA_GIF_INTERNAL
QTOPIA_AUTOCONF += -qt-gif
endif

# JPG support
ifdef PTXCONF_QTOPIA_JPG_NONE
QTOPIA_AUTOCONF += -no-libjpeg
endif
ifdef PTXCONF_QTOPIA_JPG_INTERNAL
QTOPIA_AUTOCONF += -qt-libjpeg
endif
ifdef PTXCONF_QTOPIA_JPG_SYSTEM
QTOPIA_AUTOCONF += -system-libjpeg
endif

ifdef PTXCONF_QTOPIA_ZLIB_NONE
QTOPIA_AUTOCONF += -no-zlib
endif
ifdef PTXCONF_QTOPIA_ZLIB_INTERNAL
QTOPIA_AUTOCONF += -qt-zlib
endif
ifdef PTXCONF_QTOPIA_ZLIB_SYSTEM
QTOPIA_AUTOCONF += -system-zlib
endif

ifdef PTXCONF_QTOPIA_FREETYPE_NONE
QTOPIA_AUTOCONF += -no-freetype
endif
ifdef PTXCONF_QTOPIA_FREETYPE_INTERNAL
QTOPIA_AUTOCONF += -qt-freetype
endif
ifdef PTXCONF_QTOPIA_FREETYPE_SYSTEM
QTOPIA_AUTOCONF += -system-freetype -I$(SYSROOT)/usr/include/freetype2
endif

ifdef PTXCONF_ENDIAN_LITTLE
QTOPIA_AUTOCONF += -little-endian
else
QTOPIA_AUTOCONF += -big-endian
endif

ifdef PTXCONF_QTOPIA_STL
QTOPIA_AUTOCONF	+= -stl
else
QTOPIA_AUTOCONF	+= -no-stl
endif

ifdef PTXCONF_QTOPIA_TSLIB
QTOPIA_AUTOCONF	+= -qt-mouse-tslib
endif

ifdef PTXCONF_QTOPIA_DBUS
QTOPIA_AUTOCONF += -qdbus
QTOPIA_BUILD_TOOLS_TARGETS += sub-tools-qdbus
QTOPIA_INSTALL_TARGETS += sub-tools-qdbus-install_subtargets
else
QTOPIA_AUTOCONF += -no-qdbus
endif

ifdef PTXCONF_QTOPIA_SHARED
QTOPIA_AUTOCONF += -shared
else
QTOPIA_AUTOCONF += -static
endif

ifdef PTXCONF_QTOPIA_BUILD_DESIGNERLIBS
QTOPIA_BUILD_TOOLS_TARGETS += \
	sub-tools-designer-src-uitools \
	sub-tools-designer-src-lib
QTOPIA_INSTALL_TARGETS += \
	sub-tools-designer-src-uitools-install_subtargets \
	sub-tools-designer-src-lib-install_subtargets
endif

ifdef PTXCONF_QTOPIA_BUILD_ASSISTANTLIB
QTOPIA_BUILD_TOOLS_TARGETS += sub-tools-assistant-lib
QTOPIA_INSTALL_TARGETS += sub-tools-assistant-lib-install_subtargets
endif

$(STATEDIR)/qtopia.prepare: $(qtopia_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(QTOPIA_DIR)/config.cache)
	cd $(QTOPIA_DIR) && \
		echo "yes" | $(QTOPIA_PATH) $(QTOPIA_ENV) \
		./configure $(QTOPIA_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

QTOPIA_BUILD_TOOLS_TARGETS :=
QTOPIA_INSTALL_TARGETS :=

ifdef PTXCONF_QTOPIA_BUILD_MOC
QTOPIA_BUILD_TARGETS += sub-moc
QTOPIA_INSTALL_TARGETS += sub-moc-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_RCC
QTOPIA_BUILD_TARGETS += sub-rcc
QTOPIA_INSTALL_TARGETS += sub-rcc-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_UIC
QTOPIA_BUILD_TARGETS += sub-uic
QTOPIA_INSTALL_TARGETS += sub-uic-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_CORELIB
QTOPIA_BUILD_TARGETS += sub-corelib
QTOPIA_INSTALL_TARGETS += sub-corelib-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_XML
QTOPIA_BUILD_TARGETS += sub-xml
QTOPIA_INSTALL_TARGETS += sub-xml-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_GUI
QTOPIA_BUILD_TARGETS += sub-gui
QTOPIA_INSTALL_TARGETS += sub-gui-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_SQL
QTOPIA_BUILD_TARGETS += sub-sql
QTOPIA_INSTALL_TARGETS += sub-sql-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_NETWORK
QTOPIA_BUILD_TARGETS += sub-network
QTOPIA_INSTALL_TARGETS += sub-network-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_SVG
QTOPIA_BUILD_TARGETS += sub-svg
QTOPIA_INSTALL_TARGETS += sub-svg-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_SCRIPT
QTOPIA_BUILD_TARGETS += sub-script
QTOPIA_INSTALL_TARGETS += sub-script-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_PLUGINS
QTOPIA_BUILD_TARGETS += sub-plugins
QTOPIA_INSTALL_TARGETS += sub-plugins-install_subtargets
endif
ifdef PTXCONF_QTOPIA_BUILD_QTESTLIB
QTOPIA_BUILD_TOOLS_TARGETS += sub-tools-qtestlib
QTOPIA_INSTALL_TARGETS += sub-tools-qtestlib-install_subtargets
endif

qtopia_compile: $(STATEDIR)/qtopia.compile

$(STATEDIR)/qtopia.compile: $(qtopia_compile_deps_default)
	@$(call targetinfo, $@)
ifneq ($(strip $(QTOPIA_BUILD_TARGETS)), )
	cd $(QTOPIA_DIR) && $(QTOPIA_PATH) $(MAKE) \
		$(PARALLELMFLAGS) $(QTOPIA_BUILD_TARGETS)
endif
# These targets don't have the correct dependencies.
# We have to build them later
ifneq ($(strip $(QTOPIA_BUILD_TOOLS_TARGETS)), )
	cd $(QTOPIA_DIR) && $(QTOPIA_PATH) $(MAKE) \
		$(PARALLELMFLAGS) $(QTOPIA_BUILD_TOOLS_TARGETS)
endif
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

qtopia_install: $(STATEDIR)/qtopia.install

$(STATEDIR)/qtopia.install: $(qtopia_install_deps_default)
	@$(call targetinfo, $@)
	cd $(QTOPIA_DIR) && $(QTOPIA_PATH) $(MAKE) \
		$(QTOPIA_INSTALL_TARGETS) $(QTOPIA_MAKEVARS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

qtopia_targetinstall: $(STATEDIR)/qtopia.targetinstall

$(STATEDIR)/qtopia.targetinstall: $(qtopia_targetinstall_deps_default)
	@$(call targetinfo, $@)

	@$(call install_init, qtopia)
	@$(call install_fixup,qtopia,PACKAGE,qtopia)
	@$(call install_fixup,qtopia,PRIORITY,optional)
	@$(call install_fixup,qtopia,VERSION,$(QTOPIA_VERSION))
	@$(call install_fixup,qtopia,SECTION,base)
	@$(call install_fixup,qtopia,AUTHOR,"Juergen Beisertl <j.beisert\@pengutronix.de>")
	@$(call install_fixup,qtopia,DEPENDS,)
	@$(call install_fixup,qtopia,DESCRIPTION,missing)

ifdef PTXCONF_QTOPIA_SHARED
ifdef PTXCONF_QTOPIA_BUILD_CORELIB
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtCore.so.4.3.3, /usr/lib/libQtCore.so.4.3.3 )
	@$(call install_link, qtopia, libQtCore.so.4.3.3, /usr/lib/libQtCore.so.4.3)
	@$(call install_link, qtopia, libQtCore.so.4.3.3, /usr/lib/libQtCore.so.4)
endif
ifdef PTXCONF_QTOPIA_BUILD_XML
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtXml.so.4.3.3, /usr/lib/libQtXml.so.4.3.3 )
	@$(call install_link, qtopia, libQtXml.so.4.3.3, /usr/lib/libQtXml.so.4.3)
	@$(call install_link, qtopia, libQtXml.so.4.3.3, /usr/lib/libQtXml.so.4)
endif
ifdef PTXCONF_QTOPIA_BUILD_GUI
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtGui.so.4.3.3, /usr/lib/libQtGui.so.4.3.3 )
	@$(call install_link, qtopia, libQtGui.so.4.3.3, /usr/lib/libQtGui.so.4.3)
	@$(call install_link, qtopia, libQtGui.so.4.3.3, /usr/lib/libQtGui.so.4)
endif
ifdef PTXCONF_QTOPIA_BUILD_SQL
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtSql.so.4.3.3, /usr/lib/libQtSql.so.4.3.3 )
	@$(call install_link, qtopia, libQtSql.so.4.3.3, /usr/lib/libQtSql.so.4.3)
	@$(call install_link, qtopia, libQtSql.so.4.3.3, /usr/lib/libQtSql.so.4)
endif
ifdef PTXCONF_QTOPIA_BUILD_NETWORK
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtNetwork.so.4.3.3, /usr/lib/libQtNetwork.so.4.3.3 )
	@$(call install_link, qtopia, libQtNetwork.so.4.3.3, /usr/lib/libQtNetwork.so.4.3)
	@$(call install_link, qtopia, libQtNetwork.so.4.3.3, /usr/lib/libQtNetwork.so.4)
endif
ifdef PTXCONF_QTOPIA_BUILD_SVG
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtSvg.so.4.3.3, /usr/lib/libQtSvg.so.4.3.3 )
	@$(call install_link, qtopia, libQtSvg.so.4.3.3, /usr/lib/libQtSvg.so.4.3)
	@$(call install_link, qtopia, libQtSvg.so.4.3.3, /usr/lib/libQtSvg.so.4)
endif
ifdef PTXCONF_QTOPIA_BUILD_SCRIPT
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtScript.so.4.3.3, /usr/lib/libQtScript.so.4.3.3 )
	@$(call install_link, qtopia, libQtScript.so.4.3.3, /usr/lib/libQtScript.so.4.3)
	@$(call install_link, qtopia, libQtScript.so.4.3.3, /usr/lib/libQtScript.so.4)
endif
ifdef PTXCONF_QTOPIA_BUILD_QTESTLIB
	@$(call install_copy, qtopia, 0, 0, 0644, $(QTOPIA_DIR)/lib/libQtTest.so.4.3.3, /usr/lib/libQtTest.so.4.3.3 )
	@$(call install_link, qtopia, libQtTest.so.4.3.3, /usr/lib/libQtTest.so.4.3)
	@$(call install_link, qtopia, libQtTest.so.4.3.3, /usr/lib/libQtTest.so.4)
endif
endif #PTXCONF_QTOPIA_SHARED

ifdef PTXCONF_QTOPIA_FONT_DEJAVU
	for i in \
		DejaVuSans-Bold.ttf \
		DejaVuSans-BoldOblique.ttf \
		DejaVuSans-Oblique.ttf \
		DejaVuSans.ttf \
		DejaVuSansMono-Bold.ttf \
		DejaVuSansMono-BoldOblique.ttf \
		DejaVuSansMono-Oblique.ttf \
		DejaVuSansMono.ttf \
		DejaVuSerif-Bold.ttf \
		DejaVuSerif-BoldOblique.ttf \
		DejaVuSerif-Oblique.ttf \
		DejaVuSerif.ttf; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_UT
	for i in \
		'UTBI____.pfa' \
		'UTB_____.pfa' \
		'UTI_____.pfa' \
		'UTRG____.pfa'; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_VERA
	for i in \
		Vera.ttf \
		VeraBI.ttf \
		VeraBd.ttf \
		VeraIt.ttf \
		VeraMoBI.ttf \
		VeraMoBd.ttf \
		VeraMoIt.ttf \
		VeraMono.ttf \
		VeraSe.ttf \
		VeraSeBd.ttf; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_C0
	for i in \
		c0419bt_.pfb \
		c0582bt_.pfb \
		c0583bt_.pfb \
		c0611bt_.pfb \
		c0632bt_.pfb \
		c0633bt_.pfb \
		c0648bt_.pfb \
		c0649bt_.pfb; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_COUR
	for i in \
		cour.pfa \
		courb.pfa \
		courbi.pfa \
		couri.pfa; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_CURSOR
	for i in \
		cursor.pfa; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_FIXED
	for i in \
		fixed_120_50.qpf \
		fixed_70_50.qpf; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_HELVETICA
	for i in \
		helvetica_100_50.qpf \
		helvetica_100_50i.qpf \
		helvetica_100_75.qpf \
		helvetica_100_75i.qpf \
		helvetica_120_50.qpf \
		helvetica_120_50i.qpf \
		helvetica_120_75.qpf \
		helvetica_120_75i.qpf \
		helvetica_140_50.qpf \
		helvetica_140_50i.qpf \
		helvetica_140_75.qpf \
		helvetica_140_75i.qpf \
		helvetica_180_50.qpf \
		helvetica_180_50i.qpf \
		helvetica_180_75.qpf \
		helvetica_180_75i.qpf \
		helvetica_240_50.qpf \
		helvetica_240_50i.qpf \
		helvetica_240_75.qpf \
		helvetica_240_75i.qpf \
		helvetica_80_50.qpf \
		helvetica_80_50i.qpf \
		helvetica_80_75.qpf \
		helvetica_80_75i.qpf; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i,n); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_JAPANESE
	for i in \
		japanese_230_50.qpf; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i); \
	done
endif

ifdef PTXCONF_QTOPIA_FONT_L04
	for i in \
		l047013t.pfa \
		l047016t.pfa \
		l047033t.pfa \
		l047036t.pfa \
		l048013t.pfa \
		l048016t.pfa \
		l048033t.pfa \
		l048036t.pfa \
		l049013t.pfa \
		l049016t.pfa \
		l049033t.pfa \
		l049036t.pfa; do \
	$(call install_copy, qtopia, 0, 0, 0644, \
		$(QTOPIA_DIR)/lib/fonts/$$i, \
		/usr/lib/fonts/$$i,n); \
	done
endif

ifdef PTXCONF_QTOPIA_EXAMPLES
		#for i in $(shell cd $(QTOPIA_DIR)/examples/; find . -type f -perm /+x); do
		#	$(call install_copy, qtopia, 0, 0, 0755, \
		#		$(QTOPIA_DIR)/examples/$$i, \
		#		/home/qt-examples/$$j/$$i); \
		#done
		$(call install_copy, qtopia, 0, 0, 0755, \
			$(QTOPIA_DIR)/examples/layouts/dynamiclayouts/dynamiclayouts, \
			/home/qt-examples/dynamiclayouts);
		$(call install_copy, qtopia, 0, 0, 0755, \
			$(QTOPIA_DIR)/examples/painting/basicdrawing/basicdrawing, \
			/home/qt-examples/basicdrawing);
		$(call install_copy, qtopia, 0, 0, 0755, \
			$(QTOPIA_DIR)/examples/painting/concentriccircles/concentriccircles, \
			/home/qt-examples/concentriccircles);
		$(call install_copy, qtopia, 0, 0, 0755, \
			$(QTOPIA_DIR)/examples/graphicsview/elasticnodes/elasticnodes, \
			/home/qt-examples/elasticnodes);
		$(call install_copy, qtopia, 0, 0, 0755, \
			$(QTOPIA_DIR)/examples/graphicsview/dragdroprobot/dragdroprobot, \
			/home/qt-examples/dragdroprobot);
		$(call install_copy, qtopia, 0, 0, 0755, \
			$(QTOPIA_DIR)/examples/graphicsview/collidingmice/collidingmice, \
			/home/qt-examples/collidingmice);
endif

	@$(call install_finish,qtopia)

	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

qtopia_clean:
	rm -rf $(STATEDIR)/qtopia.*
	rm -rf $(IMAGEDIR)/qtopia_*
	rm -rf $(QTOPIA_DIR)

# vim: syntax=make
